# mypy-boto3-shield

[![PyPI - mypy-boto3-shield](https://img.shields.io/pypi/v/mypy-boto3-shield.svg?color=blue)](https://pypi.org/project/mypy-boto3-shield)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-shield.svg?color=blue)](https://pypi.org/project/mypy-boto3-shield)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-shield?color=blue)](https://pypistats.org/packages/mypy-boto3-shield)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Shield 1.17.63](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/shield.html#Shield) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 4.8.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[auto-generated docs](https://github.com/vemel/mypy_boto3_builder/service_docs/mypy_boto3_shield/README.md)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-shield](#mypy-boto3-shield)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)

## How to install

Install `boto3-stubs` for `Shield` service.

```bash
python -m pip install boto3-stubs[shield]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[shield]` in your environment: `python -m pip install 'boto3-stubs[shield]'`

Both type checking and auto-complete should work for `Shield` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[shield]` in your environment: `python -m pip install 'boto3-stubs[shield]'`

Both type checking and auto-complete should work for `Shield` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[shield]` in your environment: `python -m pip install 'boto3-stubs[shield]'`
- Run `mypy` as usual

Type checking should work for `Shield` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[shield]` in your environment: `python -m pip install 'boto3-stubs[shield]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Shield` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`ShieldClient` provides annotations for `boto3.client("shield")`.

```python
import boto3

from mypy_boto3_shield import ShieldClient

client: ShieldClient = boto3.client("shield")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: ShieldClient = session.client("shield")
```

### Paginators annotations

`mypy_boto3_shield.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_shield import ShieldClient
from mypy_boto3_shield.paginator import (
    ListAttacksPaginator,
    ListProtectionsPaginator,
)

client: ShieldClient = boto3.client("shield")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_attacks_paginator: ListAttacksPaginator = client.get_paginator("list_attacks")
list_protections_paginator: ListProtectionsPaginator = client.get_paginator("list_protections")
```







### Literals

`mypy_boto3_shield.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_shield.literals import (
    AttackLayer,
    AttackPropertyIdentifier,
    AutoRenew,
    ListAttacksPaginatorName,
    ListProtectionsPaginatorName,
    ProactiveEngagementStatus,
    ProtectedResourceType,
    ProtectionGroupAggregation,
    ProtectionGroupPattern,
    SubResourceType,
    SubscriptionState,
    Unit,
)

def check_value(value: AttackLayer) -> bool:
    ...
```



### Typed dictionaries

`mypy_boto3_shield.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_shield.type_defs import (
    AttackDetailTypeDef,
    AttackPropertyTypeDef,
    AttackStatisticsDataItemTypeDef,
    AttackSummaryTypeDef,
    AttackVectorDescriptionTypeDef,
    AttackVolumeStatisticsTypeDef,
    AttackVolumeTypeDef,
    ContributorTypeDef,
    CreateProtectionResponseTypeDef,
    DescribeAttackResponseTypeDef,
    DescribeAttackStatisticsResponseTypeDef,
    DescribeDRTAccessResponseTypeDef,
    DescribeEmergencyContactSettingsResponseTypeDef,
    DescribeProtectionGroupResponseTypeDef,
    DescribeProtectionResponseTypeDef,
    DescribeSubscriptionResponseTypeDef,
    EmergencyContactTypeDef,
    GetSubscriptionStateResponseTypeDef,
    LimitTypeDef,
    ListAttacksResponseTypeDef,
    ListProtectionGroupsResponseTypeDef,
    ListProtectionsResponseTypeDef,
    ListResourcesInProtectionGroupResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    MitigationTypeDef,
    PaginatorConfigTypeDef,
    ProtectionGroupArbitraryPatternLimitsTypeDef,
    ProtectionGroupLimitsTypeDef,
    ProtectionGroupPatternTypeLimitsTypeDef,
    ProtectionGroupTypeDef,
    ProtectionLimitsTypeDef,
    ProtectionTypeDef,
    SubResourceSummaryTypeDef,
    SubscriptionLimitsTypeDef,
    SubscriptionTypeDef,
    SummarizedAttackVectorTypeDef,
    SummarizedCounterTypeDef,
    TagTypeDef,
    TimeRangeTypeDef,
)

def get_structure() -> AttackDetailTypeDef:
    return {
      ...
    }
```
